@@ -1,6 +1,5 @@
 #!/usr/bin/perl
 
-
 use strict;
 use warnings;
 
@@ -13,9 +12,14 @@ my $c = Sys::Virt->new(uri => $uri);
 
 my $dom = $c->get_domain_by_name(shift @ARGV);
 
-my @fs = $dom->get_interface_addresses(
+my @nics = $dom->get_interface_addresses(
     Sys::Virt::Domain::INTERFACE_ADDRESSES_SRC_LEASE);
 
-use Data::Dumper;
-
-print Dumper(@fs);
+foreach my $nic (@nics) {
+    print "Interface ", $nic->{name}, "\n";
+    print "   MAC: ", $nic->{hwaddr}, "\n";
+    foreach my $addr (@{$nic->{addrs}}) {
+	print "    IP: ", $addr->{addr}, "\n";
+    }
+    print "\n";
+}
